Stan Math Library: stan/math/version.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

version.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_VERSION_HPP
2 #define STAN_MATH_VERSION_HPP
3
4 #include <string>
5
6 #ifndef STAN_STRING_EXPAND
7 #define STAN_STRING_EXPAND(s) #s
8 #endif
9
10 #ifndef STAN_STRING
11 #define STAN_STRING(s) STAN_STRING_EXPAND(s)
12 #endif
13
14 #define STAN_MATH_MAJOR 2
15 #define STAN_MATH_MINOR 10
16 #define STAN_MATH_PATCH 0
17
18 namespace stan {
19 namespace math {
20
22 const std::string MAJOR_VERSION = STAN_STRING(STAN_MATH_MAJOR);
23
25 const std::string MINOR_VERSION = STAN_STRING(STAN_MATH_MINOR);
26
28 const std::string PATCH_VERSION = STAN_STRING(STAN_MATH_PATCH);
29
30 }
31 }
32
33 #endif
STAN_MATH_PATCH
#define STAN_MATH_PATCH
Definition: version.hpp:16
STAN_MATH_MAJOR
#define STAN_MATH_MAJOR
Definition: version.hpp:14
stan
Definition: log_sum_exp.hpp:8
STAN_MATH_MINOR
#define STAN_MATH_MINOR
Definition: version.hpp:15
stan::math::MINOR_VERSION
const std::string MINOR_VERSION
Minor version number for Stan math library.
Definition: version.hpp:25
stan::math::PATCH_VERSION
const std::string PATCH_VERSION
Patch version for Stan math library.
Definition: version.hpp:28
stan::math::MAJOR_VERSION
const std::string MAJOR_VERSION
Major version number for Stan math library.
Definition: version.hpp:22
STAN_STRING
#define STAN_STRING(s)
Definition: version.hpp:11

[ Stan Home Page ] © 2011–2016, Stan Development Team.